# PGL_AI
AI pdf product label reader and accuracy based seggregator
# Overview
In this project the ultimate aim is to be able to read the serial number of products from their labels stored as both in pdf and image form and check the accuracy of the numbers same in both and segregate them into 3 folders - `
1. accurately_matching
2. somewhat_matching
3. unclear
